@@ -1,12 +1,15 @@
 # ABSTRACT: Chrome Policy class
 
-use v5.36;
+use v5.37;
 use Object::Pad ':experimental';
 
 package Chrome::Policy;
+
 class Chrome::Policy :does(Chrome::Policy::Strict);
+
 use URI;
-# field url = URI -> new ('chrome://policy/');
+
+field $url :reader = URI -> new ('chrome://policy/');
 
 __END__
 
@@ -20,7 +23,7 @@ Chrome::Policy - Chrome Policy class
 
 =head1 VERSION
 
-version 0.230350
+version 0.230360
 
 Enterprise policies
 https://chromium.googlesource.com/chromium/src/+/HEAD/docs/enterprise/policies.md
