@@ -1,16 +1,21 @@
 # ABSTRACT: Chromium Policy class
 
-use v5.36;
+use v5.37;
 use Object::Pad ':experimental';
 
 package Chrome::Policy::Chromium;
-class Chrome::Policy::Chromium :isa(Chrome::Policy);
-use Path::Tiny;
-field $policy_path :reader = path '/etc/chromium/policies';
-field $managed_policy_path :reader { $self -> policy_path -> child( 'managed' ) };
-field $binary_path :reader = path '/opt/google/chrome/google-chrome';
 
-1;
+class Chrome::Policy::Chromium :isa(Chrome::Policy);
+
+use Path::Tiny;
+
+field $policy_path :reader = path '/etc/chromium-browser/policies';
+# https://askubuntu.com/questions/1324149/how-to-configure-policies-preferences-for-chromium
+# https://git.launchpad.net/~chromium-team/chromium-browser/+git/snap-from-source/commit/?id=6f2b87da50bce971f4baadae348331e1bd024cb8
+
+field $managed_policy_path :reader { $self -> policy_path -> child( 'managed' ) };
+
+field $binary_path :reader = path '/usr/bin/chromium-browser';
 
 __END__
 
@@ -24,7 +29,7 @@ Chrome::Policy::Chromium - Chromium Policy class
 
 =head1 VERSION
 
-version 0.230350
+version 0.230360
 
 =head1 AUTHOR
 
