@@ -1,11 +1,13 @@
-use v5.36;
+# ABSTRACT: Chrome strict policy role
+
+use v5.37;
 use Object::Pad;
 
 package Chrome::Policy::Strict;
 role Chrome::Policy::Strict;
 use experimental qw( builtin );
 use builtin qw( true false );
-use JSON::PP;
+use JSON::PP qw();
 use Data::Printer;
 use Path::Tiny;
 
@@ -18,7 +20,8 @@ field %policy = (
 );
 
 method set_strict_policy ( $name = 'strict.json' , $type = 'managed' ) {
-  my $policy = encode_json \%policy;
+  my $json = JSON::PP -> new -> pretty( true );
+  my $policy = $json -> encode( \%policy );
   # p $policy;
   my $file;
   if ( $type eq 'managed' ) {
@@ -28,7 +31,7 @@ method set_strict_policy ( $name = 'strict.json' , $type = 'managed' ) {
   $file -> close;
 }
 
-1;
+__END__
 
 =pod
 
@@ -36,11 +39,11 @@ method set_strict_policy ( $name = 'strict.json' , $type = 'managed' ) {
 
 =head1 NAME
 
-Chrome::Policy::Strict
+Chrome::Policy::Strict - Chrome strict policy role
 
 =head1 VERSION
 
-version 0.230350
+version 0.230360
 
 =head1 AUTHOR
 
@@ -54,11 +57,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__DATA__
-
-{
-  "ForceGoogleSafeSearch": true,
-  "ForceYouTubeRestrict": 1,
-  "SafeSitesFilterBehavior": 1,
-}
